==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/data/translations/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Добро пожаловать в %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Включен Caps Lock!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Раскладка клавиатуры</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вход</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Вход не удался</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Вход выполнен</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Введите имя пользователя и пароль</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузка</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Сессия</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Выключение</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Выберите пользователя и введите пароль</translation>
    </message>
</context>
</TS>

==> sddm_0.17.0.orig.tar.gz: sddm-0.17.0/data/translations/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Добро пожаловать на %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Внимание: нажата клавиша Caps Lock</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Раскладка клавиатуры</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Войти</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Не удалось войти в систему</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Вход выполнен</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Введите имя пользователя и пароль</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Сеанс</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Выберите пользователя и введите пароль</translation>
    </message>
</context>
</TS>
